@@ -78,10 +78,11 @@ run_geelite <- function(path,
   # Build or read grid
   grid <- get_grid(task)
   if (verbose) {
+    cat("\n")
     if (mode == "local") {
-      cat("> Extracting data from Earth Engine...\r")
+      cat("> Extracting data from Earth Engine...")
     } else if (mode == "drive") {
-      cat("> Uploading data for remote processing...\r")
+      cat("> Uploading data for remote processing...")
     }
     flush.console()
   }
@@ -141,139 +142,246 @@ print_version <- function(verbose) {
 
 #' Set Dependencies
 #'
-#' Authenticates the Google Earth Engine (GEE) account and activates the
-#' specified Conda environment.
-#' @param conda [optional] (character) Name of the virtual Conda environment
-#'   used by the \code{rgee} package (default: \code{"rgee"}).
-#' @param user [optional] (character) Specifies the Google account directory
-#'   within \code{~/.config/earthengine/}. This directory stores credentials
-#'   for a specific Google account (default: \code{NULL}).
-#' @param drive [optional] (logical) If \code{TRUE}, initializes Google Drive
-#'   authentication for tasks involving Drive exports (default: \code{TRUE}).
-#' @param verbose [optional] (logical) Display messages (default: \code{TRUE}).
+#' Activates the Conda environment used for Earth Engine, ensures that
+#' authentication exists if needed, and initializes the Earth Engine Python API.
+#' @param conda [optional] (character) Name of the Conda environment
+#'   (default: "rgee").
+#' @param user [optional] (character) Google account directory under
+#'   ~/.config/earthengine. Typically NULL unless multiple accounts are used.
+#' @param drive [optional] (logical) Whether to enable Google Drive access
+#'   (default: TRUE).
+#' @param verbose [optional] (logical) Whether to print a success message at
+#'   the end.
 #' @keywords internal
-#' @importFrom reticulate use_condaenv py_run_string
-#' @importFrom rgee ee_clean_user_credentials ee_get_earthengine_path
-#' @importFrom rgee ee_Initialize
+#' @importFrom rgee ee_Authenticate
+#' @importFrom gargle gargle_oauth_cache
+#' @importFrom reticulate use_condaenv import
+#' @importFrom googledrive drive_auth drive_user
 #'
 set_depend <- function(conda = "rgee",
                        user = NULL,
                        drive = TRUE,
                        verbose = TRUE) {
 
-  # Activate the specified Conda environment
+  # Activate the conda environment
   reticulate::use_condaenv(conda, required = TRUE)
 
-  attempt <- 1
-  success <- FALSE
-
-  # Attempt to initialize Earth Engine; try up to two times
-  while (attempt <= 2 && !success) {
-
-    # Try the standard Earth Engine initialization
-    tryCatch({
-      suppressMessages({
-        rgee::ee_Initialize(user = user, drive = drive, quiet = TRUE)
-      })
-      success <- TRUE
-    }, error = function(e) {
-
-      # Handle keyboard interrupt errors immediately
-      if (grepl("KeyboardInterrupt", e$message)) {
-        stop(e)
+  # Try importing the Earth Engine Python module
+  ee <- tryCatch(
+    reticulate::import("ee"),
+    error = function(e) {
+      stop(
+        "Failed to import the Python 'ee' module. ",
+        "Verify that 'earthengine-api' is installed in the '",
+        conda, "' environment.\n\n", e$message, call. = FALSE
+      )
+    }
+  )
+  initialized <- FALSE
+  # First attempt: Initialize using existing Python credentials
+  tryCatch(
+    {
+      ee$Initialize()
+      initialized <- TRUE
+    },
+    error = function(e) {
+      # Silent fallback; authentication will be attempted next
+    }
+  )
+  # Second attempt: Authenticate with rgee, then retry initialization
+  if (!initialized) {
+    # Run rgee authentication (this triggers browser-based token workflow)
+    tryCatch(
+      rgee::ee_Authenticate(user = user, drive = drive),
+      error = function(e) {
+        stop(
+          "Earth Engine authentication failed.\n\n",
+          e$message,
+          call. = FALSE
+        )
       }
-
-      # Attempt fallback initialization with credential cleaning if necessary
-      tryCatch({
-        if (!is.null(user)) {
-          if (!exists("credentials_path")) {
-            credentials_path <- paste0(
-              gsub("\\\\", "/", rgee::ee_get_earthengine_path()),
-              user, "/credentials"
-            )
-          }
-          reticulate::py_run_string(sprintf(
-            "import ee; ee.Initialize(credentials='%s')", credentials_path
-          ))
-        } else {
-          reticulate::py_run_string("import ee; ee.Initialize()")
-        }
-        success <- TRUE
-      }, error = function(e2) {
-        rgee::ee_clean_user_credentials(user = user)
-      })
-    })
-    attempt <- attempt + 1
+    )
+    # Re-import the ee module (to ensure credentials are now available)
+    ee <- tryCatch(
+      reticulate::import("ee"),
+      error = function(e) {
+        stop(
+          "The 'ee' Python module became unavailable after authentication.\n",
+          "Please check your Python environment.\n\n",
+          e$message,
+          call. = FALSE
+        )
+      }
+    )
+    # Final attempt: initialize Python EE API
+    tryCatch(
+      {
+        ee$Initialize()
+        initialized <- TRUE
+      },
+      error = function(e) {
+        stop(
+          "Earth Engine could not be initialized after authentication.\n",
+          "Ensure that your Google Cloud project is registered for ",
+          "Earth Engine\nand that your credentials are valid.\n\n",
+          e$message,
+          call. = FALSE
+        )
+      }
+    )
   }
 
-  # Stop execution with an error message if initialization was not successful
-  if (!success) {
-    stop(
-      "It looks like your EE credential has expired.\n",
-      "Try running rgee::ee_Authenticate() again or clean your credentials ",
-      "with rgee::ee_clean_user_credentials()."
+  # Google Drive token detection (for drive mode)
+  drive_email <- NULL
+  if (drive) {
+
+    # Make gargle/drive quieter during internal auth
+    old_opt <- options(
+      gargle_oauth_email = TRUE,
+      gargle_quiet       = TRUE
+    )
+    on.exit(options(old_opt), add = TRUE)
+
+    # Try to reuse an existing cached token non-interactively.
+    # In non-interactive sessions this should not error or prompt.
+    tryCatch(
+      {
+        suppressMessages(
+          suppressWarnings(
+            drive_auth(cache = gargle_oauth_cache())
+          )
+        )
+
+        # If auth worked, try to get the user email
+        drive_email <- tryCatch(
+          {
+            du <- suppressMessages(drive_user())
+            if (!is.null(du[["emailAddress"]])) {
+              du[["emailAddress"]]
+            } else if (!is.null(du[["user"]][["emailAddress"]])) {
+              du[["user"]][["emailAddress"]]
+            } else {
+              NULL
+            }
+          },
+          error = function(e) NULL
+        )
+      },
+      error = function(e) {
+        # No cached token / non-interactive failure -> ignore silently
+        drive_email <<- NULL
+      }
     )
   }
 
   # Print Earth Engine initialization message if verbose mode is enabled
   if (verbose) {
-    gee_message(user)
+    gee_message(user = user, drive_email = drive_email)
   }
+  invisible(TRUE)
 }
 
 # ------------------------------------------------------------------------------
 
-#' Print Google Earth Engine and Python Environment Information
+#' Print Earth Engine and Python Environment Information
 #'
-#' Prints information about the Google Earth Engine (GEE) and Python
-#' environment.
-#' @param user [mandatory] (character) Specifies the Google account directory
-#'   for which information is displayed.
+#' Prints a summary of the Earth Engine and Python environment used by
+#'   \code{geeLite}, after successful initialization.
+#' @param user [optional] (character) Optional Google account identifier to
+#'   display.
+#' @param drive_email [optional] (character) Optional Google Drive email if a
+#'   cached token was found. Used only for messaging; can be NULL.
 #' @keywords internal
 #' @importFrom cli rule
 #' @importFrom crayon green blue
 #' @importFrom utils packageVersion
-#' @importFrom reticulate py_config
-#' @importFrom rgee ee_version ee_user_info
+#' @importFrom reticulate py_config import
 #'
-gee_message <- function (user) {
+gee_message <- function(user = NULL, drive_email = NULL) {
 
-  # Retrieve version and configuration details
-  rgee_version <- as.character(utils::packageVersion("rgee"))
-  ee_version <- as.character(rgee::ee_version())
-  user_info <- if (is.null(user)) "not defined" else user
-  account_info <- rgee::ee_user_info(quiet = TRUE)[1]
-  py_path_info <- reticulate::py_config()$python
-
-  # Create header with version information
-  header <- cli::rule(
-    left = paste0("rgee ", rgee_version),
-    right = paste0("earthengine-api ", ee_version)
+  # Get versions and paths safely
+  rgee_version <- tryCatch(
+    as.character(utils::packageVersion("rgee"))[1],
+    error = function(e) "unknown"
   )
 
-  # Display the header and key configuration details
-  cat(header, "\n")
-  cat(
-    crayon::green("\u2714"),
-    crayon::blue("User:"),
-    crayon::green(user_info), "\n"
+  ee_module <- tryCatch(
+    reticulate::import("ee"),
+    error = function(e) NULL
   )
-  cat(
-    crayon::green("\u2714"),
-    crayon::blue("Initializing Google Earth Engine:"),
-    crayon::green("DONE!"), "\n"
+
+  ee_version <- if (!is.null(ee_module)) {
+    tryCatch(
+      as.character(ee_module$`__version__`)[1],
+      error = function(e) "unknown"
+    )
+  } else {
+    "unknown"
+  }
+
+  # Retrieve Python configuration
+  py_info <- tryCatch(reticulate::py_config(), error = function(e) NULL)
+
+  python_ver <- tryCatch(
+    as.character(py_info$version)[1],
+    error = function(e) "unknown"
   )
-  cat(
-    crayon::green("\u2714"),
-    crayon::blue("Earth Engine account:"),
-    crayon::green(account_info), "\n"
+
+  python_path <- tryCatch(
+    as.character(py_info$python)[1],
+    error = function(e) "unknown"
   )
+
+  # Header with rgee + earthengine-api versions
   cat(
-    crayon::green("\u2714"),
-    crayon::blue("Python path:"),
-    crayon::green(py_path_info), "\n"
+    cli::rule(
+      left  = paste0("rgee ", rgee_version),
+      right = paste0("earthengine-api ", ee_version)
+    ),
+    "\n"
   )
-  cat(cli::rule(), "\n\n")
+
+  # Body lines
+  cat(
+    crayon::green("[OK] "),
+    crayon::blue("User: "),
+    if (is.null(user)) "not specified" else user,
+    "\n", sep = ""
+  )
+
+  cat(
+    crayon::green("[OK] "),
+    crayon::blue("Earth Engine API version: "),
+    ee_version,
+    "\n", sep = ""
+  )
+
+  cat(
+    crayon::green("[OK] "),
+    crayon::blue("Python executable: "),
+    python_path,
+    "\n", sep = ""
+  )
+
+  cat(
+    crayon::green("[OK] "),
+    crayon::blue("Python version: "),
+    python_ver,
+    "\n", sep = ""
+  )
+
+  # Optional Google Drive info line, only if we have an email
+  if (!is.null(drive_email)) {
+    cat(
+      crayon::green("[OK] "),
+      crayon::blue("Google Drive token: "),
+      drive_email,
+      "\n", sep = ""
+    )
+  }
+
+  # Footer line
+  cat(cli::rule(), "\n", sep = "")
 }
 
 # ------------------------------------------------------------------------------
@@ -1132,63 +1240,91 @@ get_cases <- function(database_new, dataset_new, band_new,
 #' @import rgee
 #' @importFrom dplyr filter
 #' @importFrom magrittr %>%
-#' @importFrom tidyrgee as_tidyee
 #'
 get_images <- function(task, mode, cases, dataset, band, regions_new,
                        latest_date) {
 
   # Initialize the images list and logical parameters
-  images <- list()
+  images <- list(build = NULL, update = NULL)
   skip_band <- FALSE
   skip_update <- FALSE
 
-  # If we are building from scratch or brand new band/dataset
+  # Base ImageCollection (band selected)
+  ic_base <- rgee::ee$ImageCollection(dataset)$select(band)
+
+  # Case 1: build only (new database / dataset / band / stats / regions)
   if (cases == 1) {
-    # Only build
-    images$build <- tidyrgee::as_tidyee(
-      rgee::ee$ImageCollection(dataset)$select(band)
-    ) %>%
-      dplyr::filter(date >= task$start)
+
+    ic_build <- ic_base$filterDate(task$start, NULL)
+    images$build <- ee_as_tidyee(ic_build)
 
   } else if (cases == 2) {
-    # Only update
-    images$update <- tidyrgee::as_tidyee(
-      rgee::ee$ImageCollection(dataset)$select(band)) %>%
-      dplyr::filter(date >= task$start)
 
-    # Check if we already have the max date
+    # Case 2: update only (no new stats, no new regions)
+    ic_update <- ic_base$filterDate(task$start, NULL)
+    images$update <- ee_as_tidyee(ic_update)
+
+    # If we already have the most recent date in the table
     if (!is.null(latest_date) &&
+        length(images$update$vrt$date) > 0 &&
         latest_date >= max(as.Date(images$update$vrt$date))) {
+
       skip_update <- TRUE
-      if (!any(regions_new)) skip_band <- TRUE
-    } else {
-      images$update <- images$update %>% dplyr::filter(date > latest_date)
+      if (!any(regions_new)) {
+        skip_band <- TRUE
+      }
+
+    } else if (!is.null(latest_date) &&
+               length(images$update$vrt$date) > 0) {
+
+      # Restrict update images to dates strictly after latest_date
+      ic_update2 <- ic_base$filterDate(
+        format(latest_date + 1, "%Y-%m-%d"), NULL
+      )
+      images$update <- ee_as_tidyee(ic_update2)
     }
 
   } else if (cases == 3) {
-    # Partial: build + update
-    images$build <- tidyrgee::as_tidyee(
-      rgee::ee$ImageCollection(dataset)$select(band)) %>%
-      dplyr::filter(date >= task$start)
+
+    # Case 3: mixed (some new stats/regions, some existing)
+    ic_build <- ic_base$filterDate(task$start, NULL)
+    images$build <- ee_as_tidyee(ic_build)
 
     if (!is.null(latest_date) &&
+        length(images$build$vrt$date) > 0 &&
         latest_date < max(as.Date(images$build$vrt$date))) {
-      images$update <- tidyrgee::as_tidyee(
-        rgee::ee$ImageCollection(dataset)$select(band)) %>%
-        dplyr::filter(date > latest_date)
+
+      ic_update <- ic_base$filterDate(
+        format(latest_date + 1, "%Y-%m-%d"), NULL
+      )
+      images$update <- ee_as_tidyee(ic_update)
+
     } else {
       skip_update <- TRUE
     }
   }
 
-  # Determine batch size based on mode
-  images$batch_size <- if (mode == "local") {
-    max(floor(task$limit / length(images$build$vrt$date)), 1)
+  # Determine the number of images for batching
+  n_images <- if (!is.null(images$build)) {
+    length(images$build$vrt$date)
+  } else if (!is.null(images$update)) {
+    length(images$update$vrt$date)
   } else {
-    max(task$limit, 1)
+    0L
+  }
+
+  if (n_images == 0L) {
+    # No images found for this band → nothing to do
+    skip_band <- TRUE
+    images$batch_size <- 1L
+  } else {
+    images$batch_size <- if (mode == "local") {
+      max(floor(task$limit / n_images), 1L)
+    } else {
+      max(task$limit, 1L)
+    }
   }
 
-  # Add logical parameters to the images list
   images$skip_band <- skip_band
   images$skip_update <- skip_update
 
@@ -1197,6 +1333,41 @@ get_images <- function(task, mode, cases, dataset, band, regions_new,
 
 # ------------------------------------------------------------------------------
 
+#' Minimal Replacement for tidyrgee::as_tidyee
+#'
+#' Creates a lightweight representation of an Earth Engine
+#' \code{ee$ImageCollection}, containing the original collection and its
+#' associated dates extracted from \code{system:time_start}.
+#' @return A list with:
+#'   \code{ee_ob} (the original ImageCollection) and
+#'   \code{vrt} (list containing a \code{date} vector).
+#' @param ic [mandatory] (ee$ImageCollection) The Earth Engine image collection
+#'   to convert.
+#' @keywords internal
+#' @import rgee
+#'
+ee_as_tidyee <- function(ic) {
+  # Try to extract 'system:time_start' as a list of POSIX times
+  times <- tryCatch(
+    rgee::ee$List(ic$aggregate_array("system:time_start"))$getInfo(),
+    error = function(e) NULL
+  )
+  if (is.null(times) || length(times) == 0) {
+    dates <- as.Date(character())
+  } else {
+    times <- unlist(times)
+    dates <- as.Date(
+      as.POSIXct(times / 1000, origin = "1970-01-01", tz = "UTC")
+    )
+  }
+  list(
+    ee_ob = ic,
+    vrt   = list(date = dates)
+  )
+}
+
+# ------------------------------------------------------------------------------
+
 #' Produce Batches for Build/Update Mixed Cases
 #'
 #' Divides the grid into one or two lists of chunked sf objects,
